function [offsetsVal, signalParts] = findallphasesdiff(ResData)
    % FINDALLPHASESDIFF Return all phases differences between the two angles and their range
    %   Todo

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Abbreviation
    period = 1 / ResData.Front.trueFreq;
    nPeriodIdx = period * ResData.sampling;

    % Find peaks in the wing angles
    peakLocs1 = findallpeaks(ResData.Front.angles, nPeriodIdx);
    peakLocs2 = findallpeaks(ResData.Aft.angles, nPeriodIdx);
    npeaks = min(length(peakLocs1), length(peakLocs2));

    % Trim to same number of peaks
    peakLocs1 = peakLocs1(1:npeaks);
    peakLocs2 = peakLocs2(1:npeaks);

    % Get all offsets and round them (1° precision on the offset is plenty enough)
    offsets = getphaseoffsets(peakLocs1, peakLocs2, nPeriodIdx);
    offsets = round(offsets);
    % Remove first and last offsets (can't get one period before and one after the offset otherwise)
    offsetsVal = offsets(2:end - 1);
    peakLocs = peakLocs1(2:end - 1);

    % singalPart is one period centered on the peak
    %     signalParts =  [peakLocs(1:end - 2), peakLocs1(3:end)];
    signalParts =  round([peakLocs - nPeriodIdx / 2, peakLocs + nPeriodIdx / 2]);

end

function peakLocs = findallpeaks(signal, nPeriodIdx)
    % FINDANGLEPEAKS Find all true peaks in the signal

    maxAngle = max(signal);

    [~, peakLocs] = findpeaks(signal, ...
                              'MinPeakProminence', maxAngle / 2, ...
                              'MinPeakDistance', nPeriodIdx / 2);
end

function offsets = getphaseoffsets(peaks1, peaks2, nPeriodIdx)
    % GETPHASEOFFSETS Calculate phase offsets between every contiguous peaks
    %   Note: Offset is positive when peak2 is AFTER peak1

    offsets = (peaks2 - peaks1) * 360 / nPeriodIdx;

end
