function mainFreq = getmainfrequency(signal, sampling)
    % GETMAINFREQUENCY Return the main signal frequency
    %   Todo

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Signal parameters
    if mod(length(signal), 2) ~= 0
        signal = signal(1:end - 1);
    end
    nts = length(signal);

    % Fourier transform
    transform = fft(signal);

    fT2 = abs(transform / nts); % Two-sided spectrum
    fT1 = fT2(1:nts / 2 + 1); % Single-sided spectrum
    fT1(2:end - 1) = 2 * fT1(2:end - 1);
    freq = sampling * (0:(nts / 2)) / nts; % Frequency domain

    % Get main frequency
    [~, trueFreqIdx] = max(fT1(2:end)); % Make sure it is not zero
    mainFreq = freq(1 + trueFreqIdx);

end
