function plotclcd(ResData)
    % PLOTCLCD Plot CL/CD for each set of wing
    %   Todo

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % X-axis = flapping frequency
    % Y-axis = Cf
    % One figure per dx
    % Plot airspeeds in different colors

    %             for i = 1: size(ResData,1)
    OFFSET_STEPS = 20;

    INTERESTING_PLOTS = [
                         0.03, 2, 7.7
                         0.03, 3, 2.5
                         0.03, 3, 4.6
                         0.03, 3.5, 2.5
                         0.03, 3.5, 4.6
                         0.03, 3.5, 7.7

                         0.05, 1.25, 4.6
                         0.05, 2, 7.7
                         0.05, 3, 7.7
                         0.05, 3.5, 2.5
                         0.05, 3.5, 7.7

                         0.10, 2.5, 4.6
                         0.10, 2.5, 7.7
                         0.10, 3.5, 2.5
                         0.10, 3.5, 4.6
                         0.10, 3.5, 7.7
                        ];

    for i = 1:size(ResData, 1)
        for j = 1:size(ResData, 2)

            if isinteresting(ResData(i, j), INTERESTING_PLOTS)
                expParam = sprintf('d = %0.2f, f = %0.2f, V = %0.1f', ...
                                   ResData(i, j).Testcase.dx, ...
                                   ResData(i, j).Testcase.freq, ...
                                   ResData(i, j).Testcase.airspeed);

                clcdF = ResData(i, j).AllPhases.Front.cF(:, 3) ./ ...
                    ResData(i, j).AllPhases.Front.cF(:, 1);
                clcdA = ResData(i, j).AllPhases.Aft.cF(:, 3) ./ ...
                    ResData(i, j).AllPhases.Aft.cF(:, 1);

                offsets = ResData(i, j).AllPhases.offsets;
                cleanOffsets = -175:OFFSET_STEPS:175;
                meanOffset = nan(size(cleanOffsets));
                stdOffset = nan(size(cleanOffsets));
                for iOff = 1:length(cleanOffsets)
                    curOffsets = cleanOffsets(iOff);
                    offIdx = find(abs(offsets - curOffsets) < diff(cleanOffsets(1:2)) / 2);
                    meanOffset(iOff) = mean(offsets(offIdx));
                    stdOffset(iOff) = std(offsets(offIdx));
                    meanClCdF(iOff) = mean(clcdF(offIdx), 1);
                    stdClCdF(iOff) = std(clcdF(offIdx), 0, 1);
                    meanClCdA(iOff) = mean(clcdA(offIdx), 1);
                    stdClCdA(iOff) = std(clcdA(offIdx), 0, 1);
                end

                ynegF = -stdClCdF;
                yposF = stdClCdF;
                ynegA = -stdClCdA;
                yposA = stdClCdA;

                xneg = cleanOffsets - meanOffset - stdOffset;
                xpos = cleanOffsets - meanOffset + stdOffset;

                figure('Name', 'errorbars');
                subplot(211);
                hold on;
                plot(offsets, clcdF, 'o');
                errorbar(cleanOffsets, meanClCdF, ynegF, yposF, xneg, xpos, 'o');
                hold off;
                title(['Front module -- ', expParam]);
                setgca();

                subplot(212);
                hold on;
                plot(offsets, clcdA, 'o');
                errorbar(cleanOffsets, meanClCdA, ynegA, yposA, xneg, xpos, 'o');
                hold off;
                title(['Aft module -- ', expParam]);
                setgca();

            end
        end
    end

end

function setgca()
    % SETGCA Sets the axes parameters
    xlim([-180, 180]);
    %     ylim([-1.5, 1.5]);
    grid on;
end
