function ResData = removeinertia(ResData, ResDataWO, field)
    % REMOVEINERTIA Remove intertia forces from ResData
    %   Todo

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Calculate mean inertial forces and moments
    [ResData.(field).inertiaF, ResData.(field).inertiaM] = inertialforces(ResDataWO, field);

    % -------------------------------------------
    % For all peaks found in phase, calculate mean forces and moments
    for i = 1:length(ResData.Phase)
        if ~isempty(ResData.Phase(i).idx)
            for j = 1:size(ResData.Phase(i).idx, 1)
                syncedRange = ResData.Phase(i).idx(j, 1):ResData.Phase(i).idx(j, 2);
                meanF(j, :) = mean(ResData.(field).forces(syncedRange, :));
                meanM(j, :) = mean(ResData.(field).moments(syncedRange, :));
            end
            ResData.Phase(i).(field).rawF = mean(meanF);
            ResData.Phase(i).(field).rawM = mean(meanM);
            ResData.Phase(i).(field).forces = mean(meanF) - ResData.(field).inertiaF;
            ResData.Phase(i).(field).moments = mean(meanM) - ResData.(field).inertiaM;
        end
    end

end

function [meanForces, meanMom] = inertialforces(ResDataWO, field)

    % Get first and last peaks for wind-off conditions
    woSampling = 1 / diff(ResDataWO.time(1:2));
    woBounds = getboundingpeaks(ResDataWO.(field).angles, woSampling);
    woIdx = woBounds(1):woBounds(2);

    % Calculate mean force and moments due to inertia
    meanForces = mean(ResDataWO.(field).forces(woIdx));
    meanMom = mean(ResDataWO.(field).moments(woIdx));

end
