function [ResData] = calccoeff(ResData)
    % CALCCOEFF Calculates force and moment coefficients.
    %   TODO

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    CHORD = 0.05;
    SPAN = 2 * 0.2;
    C_TO_K = 273.15;

    for i = 1:size(ResData, 1)
        for j = 1:size(ResData, 2)
            dens = airdensity(ResData(i, j).Testcase.temp + C_TO_K, ...
                              ResData(i, j).Testcase.press);
            speed = ResData(i, j).Testcase.airspeed;

            for iPos = {'Front', 'Aft'}
                pos = string(iPos);

                for iPart = 1:size(ResData(i, j).AllPhases(1).(pos).meanF, 1)

                    coeffF = forcetocoeff(ResData(i, j).AllPhases(1).(pos).meanF(iPart, :), ...
                                          dens, speed, CHORD, SPAN, 'force');
                    coeffM = forcetocoeff(ResData(i, j).AllPhases(1).(pos).meanM(iPart, :), ...
                                          dens, speed, CHORD, SPAN, 'moment');

                    % Invert X component to represent the drag
                    % (Load sensor X axis points in opposite direction w.r.t flow)
                    coeffF(1) = -coeffF(1);

                    ResData(i, j).AllPhases(1).(pos).cF(iPart, :) = coeffF;
                    ResData(i, j).AllPhases(1).(pos).cM(iPart, :) = coeffM;

                end
            end
        end
    end

end
