function [ResData] = calctrueforces(ResData)
    % CALCTRUEFORCES Calculates true forces by substracting inertia from mean raw measure.
    %   TODO

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    for i = 1:size(ResData, 1)
        for j = 1:size(ResData, 2)
            for iPos = {'Front', 'Aft'}
                pos = string(iPos);
                indexes = ResData(i, j).AllPhases.parts;

                for iPart = 1:length(indexes)

                    % Do not remove inertia from inertial case!
                    if ResData(i, j).Testcase.airspeed ~= 0
                        % Inertia
                        inF = ResData(i, j).AllPhases(1).(pos).inertiaF;
                        inM = ResData(i, j).AllPhases(1).(pos).inertiaM;
                    else
                        inF = [0, 0, 0];
                        inM = [0, 0, 0];
                    end

                    % Raw force
                    idx = indexes(iPart, 1):indexes(iPart, 2);
                    meanFraw = mean(ResData(i, j).(pos).forces(idx, :));
                    meanMraw = mean(ResData(i, j).(pos).moments(idx, :));

                    % True value
                    ResData(i, j).AllPhases(1).(pos).meanF(iPart, :) = meanFraw - inF;
                    ResData(i, j).AllPhases(1).(pos).meanM(iPart, :) = meanMraw - inM;

                end

            end
        end
    end

end
