function [allRelDiff, meanDiff, stdDiff] = comparefrequencies(ResData)
    % COMAPREFREQUENCIES Compare the frequencies of the two sets (should be identical)
    %   Todo

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    set(0, 'defaulttextinterpreter', 'latex');

    allRelDiff = zeros(size(ResData));

    for i = 1:size(ResData, 1)
        for j = 1:size(ResData, 2)

            allFreqF(i, j) = ResData(i, j).Front.trueFreq;
            allFreqA(i, j) = ResData(i, j).Aft.trueFreq;

            allRelDiff(i, j) = abs(ResData(i, j).Front.trueFreq - ResData(i, j).Aft.trueFreq) / ...
                ResData(i, j).Front.trueFreq;

        end
    end

    allRelDiff = abs(allFreqF - allFreqA) ./ allFreqF;

    meanDiff = mean(mean(allRelDiff));
    stdDiff = mean(std(allRelDiff));

    figure('Name', 'Frequency differences');
    setcolormap();
    map = uliegecolors;

    hold on;
    for i = 1:2
        h = scatter(allFreqF(i, :), allFreqA(i, :), 'filled');
        set(h, {'markerfacecolor'}, num2cell(map(1, :), 2));
    end

    xlim([1.5, 3.5]);
    ylim(xlim);
    h = plot(xlim, xlim, '--', 'linewidth', 1.1);
    set(h, {'color'}, num2cell(map(2, :), 2));
    hold off;

    setgca();
    xlabel('$\freq_\text{front}$ [Hz]');
    ylabel('$\freq_\text{aft}$  [Hz]');

    figdir = 'figures/results/';
    filename = 'freq_diff.tex';
    save2tikz([figdir, filename], '\normalsize');

end

function setgca(varargin)

    xticks([1.5:0.5:3.5]);
    yticks([1.5:0.5:3.5]);

    set(gca, ...
        'Box', 'off', ...
        'TickDir', 'out', ...
        'TickLength', [.02 .02], ...
        'XMinorTick', 'off', ...
        'YMinorTick', 'off', ...
        'YGrid', 'off', ...
        'XGrid', 'off', ...
        'XColor', 'k', ...
        'YColor', 'k', ...
        'GridLineStyle', ':', ...
        'GridColor', 'k', ...
        'GridAlpha', 0.25, ...
        'LineWidth', 1, ...
        'FontName', 'Helvetica', ...
        'Fontsize', 14);

    if nargin > 0
        set(gca, varargin{:});
    end

end
