function [forces, moments] = readdata(file, idTable)
    % READDATA Read a data file and ouput its data.
    % -----
    % Note WindTunnel data are in the following order
    %   F_x1, F_y1, F_z1, M_x1, M_y1, M_z1, F_x2, F_y2, F_z2, M_x2, M_y2, M_z2
    % -----
    %
    % Syntax:

    %
    % Inputs:

    %
    % Output:

    %
    % See also: process_wt.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Defaults and constants
    N_SENSORS = 2; % Number of sensors, [-]
    DT = 1 / 1000; % Acquisition step (acquisition @ 1kHz), [s]
    SURFACE = 2 * 0.2 * 0.06; % FIXME (need check): Total wing surface (per module), [m^2]

    % FIXME: Temp
    TEMPERATURE = 288.15; % FIXME: Placeholder for temperature
    PRESSURE = 101325;    % FIXME: Placeholder for temperature

    % -------------------------------------------
    % Get data from the identification file
    % airspeed

    % density
    % rho = airdensity(TEMPERATURE,PRESSURE);

    % -------------------------------------------
    % Read and parse data
    rawDat = dlmread(file{:}, '\t', 1, 0); % FIXME: Better stuff

    forces = zeros(size(rawDat, 1), 3, N_SENSORS);
    moments = zeros(size(forces));

    for i = 1:N_SENSORS
        forces(:, :, i) = rawDat(:, (1:3) + 6 * (i - 1));
        moments(:, :, i) = rawDat(:, (4:6) + 6 * (i - 1));
    end

end
